# OpenShift Console API

1. [`useActivePerspective`](#useactiveperspective)
2. [`useResolvedExtensions`](#useresolvedextensions)
3. [`HorizontalNav`](#horizontalnav)
4. [`VirtualizedTable`](#virtualizedtable)
5. [`TableData`](#tabledata)
6. [`useActiveColumns`](#useactivecolumns)
7. [`ListPageHeader`](#listpageheader)
8. [`ListPageCreate`](#listpagecreate)
9. [`ListPageCreateLink`](#listpagecreatelink)
10. [`ListPageCreateButton`](#listpagecreatebutton)
11. [`ListPageCreateDropdown`](#listpagecreatedropdown)
12. [`ListPageBody`](#listpagebody)
13. [`ListPageFilter`](#listpagefilter)
14. [`useListPageFilter`](#uselistpagefilter)
15. [`ResourceLink`](#resourcelink)
16. [`useK8sModel`](#usek8smodel)
17. [`useK8sModels`](#usek8smodels)
18. [`useK8sWatchResource`](#usek8swatchresource)
19. [`useK8sWatchResources`](#usek8swatchresources)
20. [`consoleFetch`](#consolefetch)
21. [`consoleFetchJSON`](#consolefetchjson)
22. [`consoleFetchText`](#consolefetchtext)
23. [`getConsoleRequestHeaders`](#getconsolerequestheaders)
24. [`k8sGetResource`](#k8sgetresource)
25. [`k8sCreateResource`](#k8screateresource)
26. [`k8sUpdateResource`](#k8supdateresource)
27. [`k8sPatchResource`](#k8spatchresource)
28. [`k8sDeleteResource`](#k8sdeleteresource)
29. [`k8sListResource`](#k8slistresource)
30. [`getAPIVersionForModel`](#getapiversionformodel)
31. [`getGroupVersionKindForResource`](#getgroupversionkindforresource)
32. [`getGroupVersionKindForModel`](#getgroupversionkindformodel)
33. [`StatusPopupSection`](#statuspopupsection)
34. [`StatusPopupItem`](#statuspopupitem)
35. [`Overview`](#overview)
36. [`OverviewGrid`](#overviewgrid)
37. [`InventoryItem`](#inventoryitem)
38. [`InventoryItemTitle`](#inventoryitemtitle)
39. [`InventoryItemBody`](#inventoryitembody)
40. [`InventoryItemStatus`](#inventoryitemstatus)
41. [`InventoryItemLoading`](#inventoryitemloading)
42. [`useFlag`](#useflag)

---

## `useActivePerspective`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-dynamic-plugin-sdk/src/perspective/useActivePerspective.ts)






---

## `useResolvedExtensions`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-dynamic-plugin-sdk/src/api/useResolvedExtensions.ts)






---

## `HorizontalNav`

### Summary

A component that creates a Navigation bar. It takes array of NavPage objects and renderes a NavBar.<br/>Routing is handled as part of the component.



### Example


```ts
const HomePage: React.FC = (props) => {
    const page = {
      href: '/home',
      name: 'Home',
      component: () => <>Home</>
    }
    return <HorizontalNav match={props.match} pages={[page]} />
}
```








---

## `VirtualizedTable`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/Table/VirtualizedTable.tsx)






---

## `TableData`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/Table/VirtualizedTable.tsx)






---

## `useActiveColumns`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/Table/active-columns-hook.ts)






---

## `ListPageHeader`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageHeader.tsx)






---

## `ListPageCreate`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageCreate.tsx)






---

## `ListPageCreateLink`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageCreate.tsx)






---

## `ListPageCreateButton`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageCreate.tsx)






---

## `ListPageCreateDropdown`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageCreate.tsx)






---

## `ListPageBody`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageBody.tsx)






---

## `ListPageFilter`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/ListPageFilter.tsx)






---

## `useListPageFilter`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/factory/ListPage/filter-hook.ts)






---

## `ResourceLink`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/public/components/utils/resource-link.tsx)






---

## `useK8sModel`

### Summary

Hook that retrieves the k8s model for provided K8sGroupVersionKind from redux.



### Example


```ts
const Component: React.FC = () => {
  const [model, inFlight] = useK8sModel({ group: 'app'; version: 'v1'; kind: 'Deployment' });
  return ...
}
```







---

## `useK8sModels`

### Summary

Hook that retrieves all current k8s models from redux.



### Example


```ts
const Component: React.FC = () => {
  const [models, inFlight] = UseK8sModels();
  return ...
}
```







### Returns

An array with the first item as the list of k8s model and second item as inFlight status


---

## `useK8sWatchResource`

### Summary

Hook that retrieves the k8s resource along with status for loaded and error.



### Example


```ts
const Component: React.FC = () => {
  const watchRes = {
        ...
      }
  const [data, loaded, error] = UseK8sWatchResource(watchRes)
  return ...
}
```







---

## `useK8sWatchResources`

### Summary

Hook that retrieves the k8s resources along with their respective status for loaded and error.



### Example


```ts
const Component: React.FC = () => {
  const watchResources = {
        'deployment': {...},
        'pod': {...}
        ...
      }
  const {deployment, pod}  = UseK8sWatchResources(watchResources)
  return ...
}
```







---

## `consoleFetch`

### Summary

A custom wrapper around `fetch` that adds console specific headers and allows for retries and timeouts.<br/>It also validates the response status code and throws appropriate error or logs out the user if required.






---

## `consoleFetchJSON`

### Summary

A custom wrapper around `fetch` that adds console specific headers and allows for retries and timeouts.<br/>It also validates the response status code and throws appropriate error or logs out the user if required.<br/>It returns the response as a JSON object.<br/>Uses consoleFetch internally.






### Returns

A promise that resolves to the response as JSON object.<br/>*


---

## `consoleFetchText`

### Summary

A custom wrapper around `fetch` that adds console specific headers and allows for retries and timeouts.<br/>It also validates the response status code and throws appropriate error or logs out the user if required.<br/>It returns the response as a text.<br/>Uses consoleFetch internally.






### Returns

A promise that resolves to the response as text.<br/>*


---

## `getConsoleRequestHeaders`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-dynamic-plugin-sdk/src/utils/fetch/console-fetch-utils.ts)






---

## `k8sGetResource`

### Summary

It fetches a resource from the cluster, based on the provided options.<br/>If the name is provided it returns one resource else it returns all the resources matching the model.






### Returns

A promise that resolves to the response as JSON object with a resource if the name is provided<br/>else it returns all the resources matching the model. In case of failure, the promise gets rejected with HTTP error response.<br/>*


---

## `k8sCreateResource`

### Summary

It creates a resource in the cluster, based on the provided options.






### Returns

A promise that resolves to the response of the resource created.<br/>In case of failure promise gets rejected with HTTP error response.<br/>*


---

## `k8sUpdateResource`

### Summary

It updates the entire resource in the cluster, based on provided options.<br/>When a client needs to replace an existing resource entirely, they can use k8sUpdate.<br/>Alternatively can use k8sPatch to perform the partial update.






### Returns

A promise that resolves to the response of the resource updated.<br/>In case of failure promise gets rejected with HTTP error response.<br/>*


---

## `k8sPatchResource`

### Summary

It patches any resource in the cluster, based on provided options.<br/>When a client needs to perform the partial update, they can use k8sPatch.<br/>Alternatively can use k8sUpdate to replace an existing resource entirely.<br/>See more {@link https://datatracker.ietf.org/doc/html/rfc6902}






### Returns

A promise that resolves to the response of the resource patched.<br/>In case of failure promise gets rejected with HTTP error response.<br/>*


---

## `k8sDeleteResource`

### Summary

It deletes resources from the cluster, based on the provided model, resource.<br/>The garbage collection works based on 'Foreground' | 'Background', can be configured with propagationPolicy property in provided model or passed in json.



### Example


{ kind: 'DeleteOptions', apiVersion: 'v1', propagationPolicy }







### Returns

A promise that resolves to the response of kind Status.<br/>In case of failure promise gets rejected with HTTP error response.


---

## `k8sListResource`

### Summary

It lists the resources as an array in the cluster, based on provided options.






### Returns

A promise that resolves to the response<br/>*


---

## `getAPIVersionForModel`

### Summary

Provides apiVersion for a k8s model.






### Returns

The apiVersion for the model i.e `group/version`.


---

## `getGroupVersionKindForResource`

### Summary

Provides a group, version, and kind for a resource.






### Returns

The group, version, kind for the provided resource.<br/>If the resource does not have an API group, group "core" will be returned.<br/>If the resource has an invalid apiVersion then it'll throw Error.


---

## `getGroupVersionKindForModel`

### Summary

Provides a group, version, and kind for a k8s model.






### Returns

The group, version, kind for the provided model.<br/>If the model does not have an apiGroup, group "core" will be returned.


---

## `StatusPopupSection`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/status-card/StatusPopup.tsx)






---

## `StatusPopupItem`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/status-card/StatusPopup.tsx)






---

## `Overview`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/Dashboard.tsx)






---

## `OverviewGrid`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/DashboardGrid.tsx)






---

## `InventoryItem`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/inventory-card/InventoryCard.tsx)






---

## `InventoryItemTitle`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/inventory-card/InventoryCard.tsx)






---

## `InventoryItemBody`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/inventory-card/InventoryCard.tsx)






---

## `InventoryItemStatus`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/inventory-card/InventoryCard.tsx)






---

## `InventoryItemLoading`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-shared/src/components/dashboard/inventory-card/InventoryCard.tsx)






---

## `useFlag`

### Summary

[For more details please refer the implementation](https://github.com/openshift/console/tree/master/frontend/packages/console-dynamic-plugin-sdk/src/utils/flags.ts)






