import * as React from 'react';
import { HorizontalNavProps, UseResolvedExtensions, VirtualizedTableFC, TableDataProps, UseActiveColumns, ListPageHeaderProps, ListPageCreateProps, ListPageCreateLinkProps, ListPageCreateButtonProps, ListPageCreateDropdownProps, ListPageFilterProps, UseListPageFilter, ResourceLinkProps, OverviewProps, OverviewGridProps, InventoryItemTitleProps, InventoryItemBodyProps, InventoryItemStatusProps } from '../extensions/console-types';
import { StatusPopupSectionProps, StatusPopupItemProps } from '../extensions/dashboard-types';
export declare const useResolvedExtensions: UseResolvedExtensions;
/**
 * A component that creates a Navigation bar. It takes array of NavPage objects and renderes a NavBar.
 * Routing is handled as part of the component.
 * @example
 * ```ts
 * const HomePage: React.FC = (props) => {
 *     const page = {
 *       href: '/home',
 *       name: 'Home',
 *       component: () => <>Home</>
 *     }
 *     return <HorizontalNav match={props.match} pages={[page]} />
 * }
 * ```
 *
 * @param {object=} resource - The resource associated with this Navigation, an object of K8sResourceCommon type
 * @param {NavPage[]} pages - An array of page objects
 * @param {object} match - match object provided by React Router
 */
export declare const HorizontalNav: React.FC<HorizontalNavProps>;
export declare const VirtualizedTable: VirtualizedTableFC;
export declare const TableData: React.FC<TableDataProps>;
export declare const useActiveColumns: UseActiveColumns;
export declare const ListPageHeader: React.FC<ListPageHeaderProps>;
export declare const ListPageCreate: React.FC<ListPageCreateProps>;
export declare const ListPageCreateLink: React.FC<ListPageCreateLinkProps>;
export declare const ListPageCreateButton: React.FC<ListPageCreateButtonProps>;
export declare const ListPageCreateDropdown: React.FC<ListPageCreateDropdownProps>;
export declare const ListPageBody: React.FC;
export declare const ListPageFilter: React.FC<ListPageFilterProps>;
export declare const useListPageFilter: UseListPageFilter;
export declare const ResourceLink: React.FC<ResourceLinkProps>;
export { default as ResourceStatus } from '@console/dynamic-plugin-sdk/src/app/components/utils/resource-status';
export { useK8sModel, useK8sModels, useK8sWatchResource, useK8sWatchResources, } from '@console/dynamic-plugin-sdk/src/utils/k8s/hooks';
export { consoleFetch, consoleFetchJSON, consoleFetchText, } from '@console/dynamic-plugin-sdk/src/utils/fetch';
export { k8sGetResource as k8sGet, k8sCreateResource as k8sCreate, k8sUpdateResource as k8sUpdate, k8sPatchResource as k8sPatch, k8sDeleteResource as k8sDelete, k8sListResource as k8sList, } from '@console/dynamic-plugin-sdk/src/utils/k8s';
export { getAPIVersionForModel, getGroupVersionKindForResource, getGroupVersionKindForModel, } from '@console/dynamic-plugin-sdk/src/utils/k8s/k8s-ref';
export declare const StatusPopupSection: React.FC<StatusPopupSectionProps>;
export declare const StatusPopupItem: React.FC<StatusPopupItemProps>;
export declare const Overview: React.FC<OverviewProps>;
export declare const OverviewGrid: React.FC<OverviewGridProps>;
export declare const InventoryItem: React.FC;
export declare const InventoryItemTitle: React.FC<InventoryItemTitleProps>;
export declare const InventoryItemBody: React.FC<InventoryItemBodyProps>;
export declare const InventoryItemStatus: React.FC<InventoryItemStatusProps>;
export declare const InventoryItemLoading: React.FC;
export { useFlag } from '@console/dynamic-plugin-sdk/src/utils/flags';
