export const useResolvedExtensions = require('@console/dynamic-plugin-sdk/src/api/useResolvedExtensions')
    .useResolvedExtensions;
/**
 * A component that creates a Navigation bar. It takes array of NavPage objects and renderes a NavBar.
 * Routing is handled as part of the component.
 * @example
 * ```ts
 * const HomePage: React.FC = (props) => {
 *     const page = {
 *       href: '/home',
 *       name: 'Home',
 *       component: () => <>Home</>
 *     }
 *     return <HorizontalNav match={props.match} pages={[page]} />
 * }
 * ```
 *
 * @param {object=} resource - The resource associated with this Navigation, an object of K8sResourceCommon type
 * @param {NavPage[]} pages - An array of page objects
 * @param {object} match - match object provided by React Router
 */
export const HorizontalNav = require('@console/internal/components/utils/horizontal-nav')
    .HorizontalNavFacade;
export const VirtualizedTable = require('@console/internal/components/factory/Table/VirtualizedTable')
    .default;
export const TableData = require('@console/internal/components/factory/Table/VirtualizedTable')
    .TableData;
export const useActiveColumns = require('@console/internal/components/factory/Table/active-columns-hook')
    .useActiveColumns;
export const ListPageHeader = require('@console/internal/components/factory/ListPage/ListPageHeader')
    .default;
export const ListPageCreate = require('@console/internal/components/factory/ListPage/ListPageCreate')
    .default;
export const ListPageCreateLink = require('@console/internal/components/factory/ListPage/ListPageCreate')
    .ListPageCreateLink;
export const ListPageCreateButton = require('@console/internal/components/factory/ListPage/ListPageCreate')
    .ListPageCreateButton;
export const ListPageCreateDropdown = require('@console/internal/components/factory/ListPage/ListPageCreate')
    .ListPageCreateDropdown;
export const ListPageBody = require('@console/internal/components/factory/ListPage/ListPageBody')
    .default;
export const ListPageFilter = require('@console/internal/components/factory/ListPage/ListPageFilter')
    .default;
export const useListPageFilter = require('@console/internal/components/factory/ListPage/filter-hook')
    .useListPageFilter;
export const ResourceLink = require('@console/internal/components/utils/resource-link')
    .ResourceLink;
export { default as ResourceStatus } from '@console/dynamic-plugin-sdk/src/app/components/utils/resource-status';
export { useK8sModel, useK8sModels, useK8sWatchResource, useK8sWatchResources, } from '@console/dynamic-plugin-sdk/src/utils/k8s/hooks';
export { consoleFetch, consoleFetchJSON, consoleFetchText, } from '@console/dynamic-plugin-sdk/src/utils/fetch';
// Expose K8s CRUD utilities as below
export { k8sGetResource as k8sGet, k8sCreateResource as k8sCreate, k8sUpdateResource as k8sUpdate, k8sPatchResource as k8sPatch, k8sDeleteResource as k8sDelete, k8sListResource as k8sList, } from '@console/dynamic-plugin-sdk/src/utils/k8s';
export { getAPIVersionForModel, getGroupVersionKindForResource, getGroupVersionKindForModel, } from '@console/dynamic-plugin-sdk/src/utils/k8s/k8s-ref';
export const StatusPopupSection = require('@console/shared/src/components/dashboard/status-card/StatusPopup')
    .StatusPopupSection;
export const StatusPopupItem = require('@console/shared/src/components/dashboard/status-card/StatusPopup')
    .default;
export const Overview = require('@console/shared/src/components/dashboard/Dashboard')
    .default;
export const OverviewGrid = require('@console/shared/src/components/dashboard/DashboardGrid')
    .default;
export const InventoryItem = require('@console/shared/src/components/dashboard/inventory-card/InventoryCard')
    .default;
export const InventoryItemTitle = require('@console/shared/src/components/dashboard/inventory-card/InventoryCard')
    .InventoryItemTitle;
export const InventoryItemBody = require('@console/shared/src/components/dashboard/inventory-card/InventoryCard')
    .InventoryItemBody;
export const InventoryItemStatus = require('@console/shared/src/components/dashboard/inventory-card/InventoryCard')
    .InventoryItemStatus;
export const InventoryItemLoading = require('@console/shared/src/components/dashboard/inventory-card/InventoryCard')
    .InventoryItemLoading;
export { useFlag } from '@console/dynamic-plugin-sdk/src/utils/flags';
//# sourceMappingURL=dynamic-core-api.js.map